pub struct WebResourceMethods<'a, C>where
C: 'a,{ /* private fields */ }Expand description
A builder providing access to all methods supported on webResource resources.
It is not used directly, but through the SiteVerification hub.
Example
Instantiate a resource builder
extern crate hyper;
extern crate hyper_rustls;
extern crate google_siteverification1 as siteverification1;
use siteverification1::{SiteVerification, FieldMask, hyper_rustls, hyper_util, yup_oauth2};
let secret: yup_oauth2::ApplicationSecret = Default::default();
let connector = hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_only()
.enable_http2()
.build();
let executor = hyper_util::rt::TokioExecutor::new();
let auth = yup_oauth2::InstalledFlowAuthenticator::with_client(
secret,
yup_oauth2::InstalledFlowReturnMethod::HTTPRedirect,
yup_oauth2::client::CustomHyperClientBuilder::from(
hyper_util::client::legacy::Client::builder(executor).build(connector),
),
).build().await.unwrap();
let client = hyper_util::client::legacy::Client::builder(
hyper_util::rt::TokioExecutor::new()
)
.build(
hyper_rustls::HttpsConnectorBuilder::new()
.with_native_roots()
.unwrap()
.https_or_http()
.enable_http2()
.build()
);
let mut hub = SiteVerification::new(client, auth);
// Usually you wouldn't bind this to a variable, but keep calling *CallBuilders*
// like `delete(...)`, `get(...)`, `get_token(...)`, `insert(...)`, `list(...)`, `patch(...)` and `update(...)`
// to build up your call.
let rb = hub.web_resource();Implementations
Sourceimpl<'a, C> WebResourceMethods<'a, C>
impl<'a, C> WebResourceMethods<'a, C>
Sourcepub fn delete(&self, id: &str) -> WebResourceDeleteCall<'a, C>
pub fn delete(&self, id: &str) -> WebResourceDeleteCall<'a, C>
Create a builder to help you perform the following task:
Relinquish ownership of a website or domain.
Arguments
id- The id of a verified site or domain.
Sourcepub fn get(&self, id: &str) -> WebResourceGetCall<'a, C>
pub fn get(&self, id: &str) -> WebResourceGetCall<'a, C>
Create a builder to help you perform the following task:
Get the most current data for a website or domain.
Arguments
id- The id of a verified site or domain.
Sourcepub fn get_token(
&self,
request: SiteVerificationWebResourceGettokenRequest,
) -> WebResourceGetTokenCall<'a, C>
pub fn get_token( &self, request: SiteVerificationWebResourceGettokenRequest, ) -> WebResourceGetTokenCall<'a, C>
Create a builder to help you perform the following task:
Get a verification token for placing on a website or domain.
Arguments
request- No description provided.
Sourcepub fn insert(
&self,
request: SiteVerificationWebResourceResource,
verification_method: &str,
) -> WebResourceInsertCall<'a, C>
pub fn insert( &self, request: SiteVerificationWebResourceResource, verification_method: &str, ) -> WebResourceInsertCall<'a, C>
Create a builder to help you perform the following task:
Attempt verification of a website or domain.
Arguments
request- No description provided.verificationMethod- The method to use for verifying a site or domain.
Sourcepub fn list(&self) -> WebResourceListCall<'a, C>
pub fn list(&self) -> WebResourceListCall<'a, C>
Create a builder to help you perform the following task:
Get the list of your verified websites and domains.
Sourcepub fn patch(
&self,
request: SiteVerificationWebResourceResource,
id: &str,
) -> WebResourcePatchCall<'a, C>
pub fn patch( &self, request: SiteVerificationWebResourceResource, id: &str, ) -> WebResourcePatchCall<'a, C>
Create a builder to help you perform the following task:
Modify the list of owners for your website or domain. This method supports patch semantics.
Arguments
request- No description provided.id- The id of a verified site or domain.
Sourcepub fn update(
&self,
request: SiteVerificationWebResourceResource,
id: &str,
) -> WebResourceUpdateCall<'a, C>
pub fn update( &self, request: SiteVerificationWebResourceResource, id: &str, ) -> WebResourceUpdateCall<'a, C>
Create a builder to help you perform the following task:
Modify the list of owners for your website or domain.
Arguments
request- No description provided.id- The id of a verified site or domain.